EventResource

Struct EventResource 

pub struct EventResource { /* private fields */ }
Tracks event resource.

Implementations

Source

impl EventResource

pub fn create(&self, event: Event)

Publish an event fire-and-forget in a background thread.

Errors are silently swallowed so that tracking failures never interrupt the caller’s normal flow. Call EventResource::flush before process exit to ensure all in-flight events are delivered.

Panics

Does not panic. If event.metadata is not a JSON object the event is silently dropped.

pub fn flush(&self)

Block until all in-flight events have been sent or exhausted their retries.

Call this before process exit to avoid dropping events that are still being delivered in background threads.